==> bbwa-0.0.5.tar.gz: bbwa-0.0.5/comment_i.php <==
<?php
//
// BBWA
// comment_i.php
// Ȥ񤭹 ()
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<html>
<head>
<title>BBWA</title>
</head>
<body>


<?php
include("variables.php");
include("functions.php");

// SJIS ǽ
mb_http_output("SJIS");
ob_start(mb_output_handler);

// 
if (trim($_GET['repCom']) != "") {
  if (trim($_GET['repName']) == "") {
    $repName = "̾ʤ";
  } else {
    $repName = mb_convert_encoding($_GET['repName'], "EUC-JP", "auto");
  }
  $repCom = mb_convert_encoding($_GET['repCom'], "EUC-JP", "auto");
  $repCom = eregi_replace("\r\n|\r|\n", "{{BR}}", $repCom);
  $repCom = eregi_replace("<", "{{LT}}", $repCom);
  $repCom = eregi_replace(">", "{{GT}}", $repCom);

  $repTime = date("n/j G:i");

  $filePtr =
    fopen("${dirName}Messages/${_GET['repImg']}_mes.txt", "a");
  while (!flock($filePtr, LOCK_EX)) {};
  fwrite($filePtr, "${repName}|||${repCom}|||${repTime}\n");
  flock($filePtr, LOCK_UN);
  fclose($filePtr);

  // ǥå
  $oldList = file("${dirName}INDEX");
  $filePtr = fopen("${dirName}INDEX", "w");
  while (!flock($filePtr, LOCK_EX)) {};
  foreach ($oldList as $listText) {
    if (!strstr($listText, $_GET['repImg'])) {
      $listText = trim($listText);
      fwrite($filePtr, "${listText}\n");
    }
  }
  $listTime = time();
  $listText = "${_GET['repImg']}|||${listTime}\n";
  fwrite($filePtr, $listText);
  flock($filePtr, LOCK_UN);
  fclose($filePtr);

  print("ȤƤޤ<br>");
} else {
  print("顼:ʸϤƤ<br>");
}

print("<a href=\"index_i.php?img=${_GET['repImg']}\"></a>");
?>


</body>
</html>

==> bbwa-0.0.6.tar.gz: bbwa-0.0.6/comment_i.php <==
<?php
//
// BBWA
// comment_i.php
// Ȥ񤭹 ()
// Teppei KAKU <teppei@sat.co.jp>
//
?>


<html>
<head>
<title>BBWA</title>
</head>
<body>


<?php
include("variables.php");
include("functions.php");

// SJIS ǽ
mb_http_output("SJIS");
ob_start(mb_output_handler);

// 
if (trim($_GET['repCom']) != "") {
  if (trim($_GET['repName']) == "") {
    $repName = "̾ʤ";
  } else {
    $repName = mb_convert_encoding($_GET['repName'], "EUC-JP", "auto");
  }
  $repCom = mb_convert_encoding($_GET['repCom'], "EUC-JP", "auto");
  $repCom = eregi_replace("\r\n|\r|\n", "{{BR}}", $repCom);
  $repCom = eregi_replace("<", "{{LT}}", $repCom);
  $repCom = eregi_replace(">", "{{GT}}", $repCom);

  $repTime = date("n/j G:i");

  $filePtr =
    fopen("${dirName}Messages/${_GET['repImg']}_mes.txt", "a");
  while (!flock($filePtr, LOCK_EX)) {};
  fwrite($filePtr, "${repName}|||${repCom}|||${repTime}\n");
  flock($filePtr, LOCK_UN);
  fclose($filePtr);

  // ǥå
  $oldList = file("${dirName}INDEX");
  $filePtr = fopen("${dirName}INDEX", "w");
  while (!flock($filePtr, LOCK_EX)) {};
  foreach ($oldList as $listText) {
    $listText = trim($listText);
    if (!strstr($listText, $_GET['repImg'])) {
      fwrite($filePtr, "${listText}\n");
    } else {
      $piece = explode("|||", $listText);
    }
  }
  $listTime = time();
  $listText = "${_GET['repImg']}|||${listTime}|||${piece[2]}|||${piece[3]}\n";
  fwrite($filePtr, $listText);
  flock($filePtr, LOCK_UN);
  fclose($filePtr);

  print("ȤƤޤ<br>");
} else {
  print("顼:ʸϤƤ<br>");
}

print("<a href=\"index_i.php?img=${_GET['repImg']}\"></a>");
?>


</body>
</html>
